[codecov-image]: https://codecov.io/gh/karjanme/airnowpy/branch/main/graph/badge.svg
[codecov-url]: https://codecov.io/gh/karjanme/airnowpy
[downloads-image]:https://static.pepy.tech/badge/airnowpy
[downloads-url]: https://pepy.tech/project/airnowpy
[github-actions-image]: https://github.com/karjanme/airnowpy/actions/workflows/main.yml/badge.svg?branch=main
[github-actions-url]: https://github.com/karjanme/airnowpy/actions?query=workflow%3A%22Main+Workflow%22+branch%3Amain
[pypi-image]: https://badge.fury.io/py/airnowpy.svg
[pypi-url]: https://badge.fury.io/py/airnowpy

[![PyPi][pypi-image]][pypi-url]
[![GitHub Actions][github-actions-image]][github-actions-url]
[![Downloads][downloads-image]][downloads-url]
[![Code Coverage][codecov-image]][codecov-url]

# AirNowPy

A Python library to facilitate interactions with the [AirNow API](https://docs.airnowapi.org/) web service.

## Quick Start

In order to use this library an API key is required. Get one [here](https://docs.airnowapi.org/account/request/).

## License

[MIT License](https://github.com/karjanme/airnowpy/blob/main/LICENSE)
